@@ -10,9 +10,10 @@ from functools import lru_cache, partial
 from keyword import iskeyword
 
 import attr
+
 import pycodestyle
 
-__version__ = "21.3.2"
+__version__ = "21.9.1"
 
 LOG = logging.getLogger("flake8.bugbear")
 
@@ -225,14 +226,7 @@ class BugBearVisitor(ast.NodeVisitor):
 
     def visit_Call(self, node):
         if isinstance(node.func, ast.Attribute):
-            for bug in (B301, B302, B305):
-                if node.func.attr in bug.methods:
-                    call_path = ".".join(self.compose_call_path(node.func.value))
-                    if call_path not in bug.valid_paths:
-                        self.errors.append(bug(node.lineno, node.col_offset))
-                    break
-            else:
-                self.check_for_b005(node)
+            self.check_for_b005(node)
         else:
             with suppress(AttributeError, IndexError):
                 if (
@@ -257,25 +251,8 @@ class BugBearVisitor(ast.NodeVisitor):
 
         self.generic_visit(node)
 
-    def visit_Attribute(self, node):
-        call_path = list(self.compose_call_path(node))
-        if ".".join(call_path) == "sys.maxint":
-            self.errors.append(B304(node.lineno, node.col_offset))
-        elif len(call_path) == 2 and call_path[1] == "message":
-            name = call_path[0]
-            for elem in reversed(self.node_stack[:-1]):
-                if isinstance(elem, ast.ExceptHandler) and elem.name == name:
-                    self.errors.append(B306(node.lineno, node.col_offset))
-                    break
-
     def visit_Assign(self, node):
-        if isinstance(self.node_stack[-2], ast.ClassDef):
-            # note: by hasattr below we're ignoring starred arguments, slices
-            # and tuples for simplicity.
-            assign_targets = {t.id for t in node.targets if hasattr(t, "id")}
-            if "__metaclass__" in assign_targets:
-                self.errors.append(B303(node.lineno, node.col_offset))
-        elif len(node.targets) == 1:
+        if len(node.targets) == 1:
             t = node.targets[0]
             if isinstance(t, ast.Attribute) and isinstance(t.value, ast.Name):
                 if (t.value.id, t.attr) == ("os", "environ"):
@@ -315,6 +292,11 @@ class BugBearVisitor(ast.NodeVisitor):
 
     def visit_Raise(self, node):
         self.check_for_b016(node)
+        self.check_for_b904(node)
+        self.generic_visit(node)
+
+    def visit_With(self, node):
+        self.check_for_b017(node)
         self.generic_visit(node)
 
     def compose_call_path(self, node):
@@ -423,6 +405,43 @@ class BugBearVisitor(ast.NodeVisitor):
         if isinstance(node.exc, (ast.NameConstant, ast.Num, ast.Str)):
             self.errors.append(B016(node.lineno, node.col_offset))
 
+    def check_for_b017(self, node):
+        """Checks for use of the evil syntax 'with assertRaises(Exception):'
+
+        This form of assertRaises will catch everything that subclasses
+        Exception, which happens to be the vast majority of Python internal
+        errors, including the ones raised when a non-existing method/function
+        is called, or a function is called with an invalid dictionary key
+        lookup.
+        """
+        item = node.items[0]
+        item_context = item.context_expr
+        if (
+            hasattr(item_context, "func")
+            and hasattr(item_context.func, "attr")  # noqa W503
+            and item_context.func.attr == "assertRaises"  # noqa W503
+            and len(item_context.args) == 1  # noqa W503
+            and isinstance(item_context.args[0], ast.Name)  # noqa W503
+            and item_context.args[0].id == "Exception"  # noqa W503
+            and not item.optional_vars  # noqa W503
+        ):
+            self.errors.append(B017(node.lineno, node.col_offset))
+
+    def check_for_b904(self, node):
+        """Checks `raise` without `from` inside an `except` clause.
+
+        In these cases, you should use explicit exception chaining from the
+        earlier error, or suppress it with `raise ... from None`.  See
+        https://docs.python.org/3/tutorial/errors.html#exception-chaining
+        """
+        if (
+            node.cause is None
+            and node.exc is not None
+            and not (isinstance(node.exc, ast.Name) and node.exc.id.islower())
+            and any(isinstance(n, ast.ExceptHandler) for n in self.node_stack)
+        ):
+            self.errors.append(B904(node.lineno, node.col_offset))
+
     def walk_function_body(self, node):
         def _loop(parent, node):
             if isinstance(node, (ast.AsyncFunctionDef, ast.FunctionDef)):
@@ -667,6 +686,13 @@ B008.immutable_calls = {
     "frozenset",
     "types.MappingProxyType",
     "MappingProxyType",
+    "re.compile",
+    "operator.attrgetter",
+    "operator.itemgetter",
+    "operator.methodcaller",
+    "attrgetter",
+    "itemgetter",
+    "methodcaller",
 }
 B009 = Error(
     message=(
@@ -727,58 +753,13 @@ B016 = Error(
         "an Exception?"
     )
 )
-
-# Those could be false positives but it's more dangerous to let them slip
-# through if they're not.
-B301 = Error(
+B017 = Error(
     message=(
-        "B301 Python 3 does not include `.iter*` methods on dictionaries. "
-        "Remove the `iter` prefix from the method name. For Python 2 "
-        "compatibility, prefer the Python 3 equivalent unless you expect "
-        "the size of the container to be large or unbounded. Then use "
-        "`six.iter*` or `future.utils.iter*`."
-    )
-)
-B301.methods = {"iterkeys", "itervalues", "iteritems", "iterlists"}
-B301.valid_paths = {"six", "future.utils", "builtins"}
-
-B302 = Error(
-    message=(
-        "B302 Python 3 does not include `.view*` methods on dictionaries. "
-        "Remove the `view` prefix from the method name. For Python 2 "
-        "compatibility, prefer the Python 3 equivalent unless you expect "
-        "the size of the container to be large or unbounded. Then use "
-        "`six.view*` or `future.utils.view*`."
-    )
-)
-B302.methods = {"viewkeys", "viewvalues", "viewitems", "viewlists"}
-B302.valid_paths = {"six", "future.utils", "builtins"}
-
-B303 = Error(
-    message=(
-        "B303 `__metaclass__` does nothing on Python 3. Use "
-        "`class MyClass(BaseClass, metaclass=...)`. For Python 2 "
-        "compatibility, use `six.add_metaclass`."
-    )
-)
-
-B304 = Error(message="B304 `sys.maxint` is not a thing on Python 3. Use `sys.maxsize`.")
-
-B305 = Error(
-    message=(
-        "B305 `.next()` is not a thing on Python 3. Use the `next()` "
-        "builtin. For Python 2 compatibility, use `six.next()`."
-    )
-)
-B305.methods = {"next"}
-B305.valid_paths = {"six", "future.utils", "builtins"}
-
-B306 = Error(
-    message=(
-        "B306 `BaseException.message` has been deprecated as of Python "
-        "2.6 and is removed in Python 3. Use `str(e)` to access the "
-        "user-readable message. Use `e.args` to access arguments passed "
-        "to the exception."
+        "B017 assertRaises(Exception): should be considered evil. "
+        "It can lead to your test passing even if the code being tested is "
+        "never executed due to a typo. Either assert for a more specific "
+        "exception (builtin or custom), use assertRaisesRegex, or use the "
+        "context manager form of assertRaises."
     )
 )
 
@@ -810,6 +791,14 @@ B903 = Error(
     )
 )
 
+B904 = Error(
+    message=(
+        "B904 Within an `except` clause, raise exceptions with `raise ... from err` "
+        "or `raise ... from None` to distinguish them from errors in exception handling.  "
+        "See https://docs.python.org/3/tutorial/errors.html#exception-chaining for details."
+    )
+)
+
 B950 = Error(message="B950 line too long ({} > {} characters)")
 
-disabled_by_default = ["B901", "B902", "B903", "B950"]
+disabled_by_default = ["B901", "B902", "B903", "B904", "B950"]
