@@ -27,12 +27,8 @@ from bugbear import (
     B014,
     B015,
     B016,
-    B301,
-    B302,
-    B303,
-    B304,
-    B305,
-    B306,
+    B017,
+    B904,
     B901,
     B902,
     B903,
@@ -98,15 +94,15 @@ class BugbearTestCase(unittest.TestCase):
         self.assertEqual(
             errors,
             self.errors(
-                B006(26, 24),
-                B006(30, 29),
-                B006(34, 19),
-                B006(38, 19),
-                B006(42, 31),
-                B008(51, 38),
-                B006(67, 32),
-                B008(95, 29),
-                B008(99, 44),
+                B006(29, 24),
+                B006(33, 29),
+                B006(37, 19),
+                B006(41, 19),
+                B006(45, 31),
+                B008(54, 38),
+                B006(70, 32),
+                B008(98, 29),
+                B008(102, 44),
             ),
         )
 
@@ -205,37 +201,12 @@ class BugbearTestCase(unittest.TestCase):
         expected = self.errors(B016(6, 0), B016(7, 0), B016(8, 0))
         self.assertEqual(errors, expected)
 
-    def test_b301_b302_b305(self):
-        filename = Path(__file__).absolute().parent / "b301_b302_b305.py"
+    def test_b017(self):
+        filename = Path(__file__).absolute().parent / "b017.py"
         bbc = BugBearChecker(filename=str(filename))
         errors = list(bbc.run())
-        self.assertEqual(
-            errors,
-            self.errors(
-                B301(39, 4),
-                B301(40, 4),
-                B301(41, 4),
-                B301(42, 4),
-                B302(43, 4),
-                B302(44, 4),
-                B302(45, 4),
-                B302(46, 4),
-                B305(47, 4),
-                B305(48, 4),
-            ),
-        )
-
-    def test_b303_b304(self):
-        filename = Path(__file__).absolute().parent / "b303_b304.py"
-        bbc = BugBearChecker(filename=str(filename))
-        errors = list(bbc.run())
-        self.assertEqual(errors, self.errors(B303(25, 4), B304(46, 4)))
-
-    def test_b306(self):
-        filename = Path(__file__).absolute().parent / "b306.py"
-        bbc = BugBearChecker(filename=str(filename))
-        errors = list(bbc.run())
-        self.assertEqual(errors, self.errors(B306(9, 10)))
+        expected = self.errors(B017(22, 8))
+        self.assertEqual(errors, expected)
 
     def test_b901(self):
         filename = Path(__file__).absolute().parent / "b901.py"
@@ -290,6 +261,17 @@ class BugbearTestCase(unittest.TestCase):
         errors = list(bbc.run())
         self.assertEqual(errors, self.errors(B903(32, 0), B903(38, 0)))
 
+    def test_b904(self):
+        filename = Path(__file__).absolute().parent / "b904.py"
+        bbc = BugBearChecker(filename=str(filename))
+        errors = list(bbc.run())
+        expected = [
+            B904(10, 8),
+            B904(11, 4),
+            B904(16, 4),
+        ]
+        self.assertEqual(errors, self.errors(*expected))
+
     def test_b950(self):
         filename = Path(__file__).absolute().parent / "b950.py"
         bbc = BugBearChecker(filename=str(filename))
